@@ -19,22 +19,33 @@ from dbt.adapters.firebolt.relation import FireboltRelation
 
 @dataclass
 class FireboltIndexConfig(dbtClassMixin):
-    type: str
-    join_column: Optional[str] = None
-    key_column: Optional[str] = None
+    index_type: str
+    join_columns: Optional[Union[str, List[str]]] = None
+    key_columns: Optional[Union[str, List[str]]] = None
     dimension_column: Optional[Union[str, List[str]]] = None
     aggregation: Optional[Union[str, List[str]]] = None
 
-    def render(self, relation):
+    def render_name(self, relation):
         """
-        Name the index according to the following format, joined by `_`:
-        relation name, key/join column, index type, timestamp (unix & UTC)
-        example index name: my_model_customer_id_join_1633504263.
+        Name an index according to the following format, joined by `_`:
+        index type, relation name, key/join columns, timestamp (unix & UTC)
+        example index name: join_my_model_customer_id_1633504263.
         """
-        now_unix = time.mktime(datetime.utcnow().timetuple())
-        spine_col = self.key_column if self.key_column else self.join_column
-        inputs = [relation.identifier, spine_col, str(self.type), str(int(now_unix))]
-        string = '__'.join(inputs)[0:254]
+        now_unix = str(int(time.mktime(datetime.utcnow().timetuple())))
+        # If column_names is a list with > 1 members, join with _,
+        # otherwise do not. We were getting index names like
+        # join__idx__emf_customers__f_i_r_s_t___n_a_m_e__165093112.
+        column_names = self.key_columns or self.join_columns
+        spine_col = (
+            '_'.join(column_names) if isinstance(column_names, list) else column_names
+        )
+        inputs = [
+            f'{self.index_type}_idx',
+            relation.identifier,
+            spine_col,
+            now_unix,
+        ]
+        string = '__'.join(inputs)
         return string
 
     @classmethod
@@ -48,40 +59,35 @@ class FireboltIndexConfig(dbtClassMixin):
             return None
         try:
             cls.validate(raw_index)
-
             index_config = cls.from_dict(raw_index)
-
-            if index_config.type.upper() not in ['JOIN', 'AGGREGATING']:
+            if index_config.index_type.upper() not in ['JOIN', 'AGGREGATING']:
                 dbt.exceptions.raise_compiler_error(
-                    f'Invalid index type:\n'
-                    f'  Got: {index_config.type}\n'
-                    f'  type should be either: "join" or "aggregating"'
+                    'Invalid index type:\n'
+                    f'  Got: {index_config.index_type}.\n'
+                    '  Type should be either: "join" or "aggregating."'
                 )
-            elif index_config.type == 'join' and not (
-                index_config.join_column and index_config.dimension_column
+            if index_config.index_type.upper() == 'JOIN' and not (
+                index_config.join_columns and index_config.dimension_column
             ):
-
                 dbt.exceptions.raise_compiler_error(
-                    f'Invalid join index definition:\n'
-                    f'  Got: {index_config}\n'
-                    f'  join_column and dimension_column must be specified '
-                    '  for join indexes'
+                    'Invalid join index definition:\n'
+                    f'  Got: {index_config}.\n'
+                    '  join_columns and dimension_column must be specified '
+                    'for join indexes.'
                 )
-            elif index_config.type == 'aggregating' and not (
-                index_config.key_column and index_config.aggregation
+            if index_config.index_type.upper() == 'AGGREGATING' and not (
+                index_config.key_columns and index_config.aggregation
             ):
-
                 dbt.exceptions.raise_compiler_error(
-                    f'Invalid aggregating index definition:\n'
-                    f'  Got: {index_config}\n'
-                    f'  key_column and aggregation must be specified'
-                    '  for join indexes'
+                    'Invalid aggregating index definition:\n'
+                    f'  Got: {index_config}.\n'
+                    '  key_columns and aggregation must be specified '
+                    'for aggregating indexes.'
                 )
-            else:
-                return index_config
+            return index_config
         except ValidationError as exc:
             msg = dbt.exceptions.validator_error_message(exc)
-            dbt.exceptions.raise_compiler_error(f'Could not parse index config: {msg}')
+            dbt.exceptions.raise_compiler_error(f'Could not parse index config: {msg}.')
 
 
 @dataclass
@@ -124,31 +130,6 @@ class FireboltAdapter(SQLAdapter):
             '`convert_time_type` is not implemented for this adapter!'
         )
 
-    @available.parse_none
-    def reformat_view_results(self, agate_table, schema_relation) -> agate.Table:
-        """
-        Tweak `SHOW VIEWS` to match the output of information_schema.tables
-        before they are unioned.
-        """
-
-        def form_sing_val_col(string_val) -> agate.Formula:
-            """Return wrapper for creating agate.Formula objects"""
-            return agate.Formula(agate.Text(), lambda r: string_val)
-
-        agate_new = (
-            agate_table.exclude(['schema'])
-            .rename(column_names={'view_name': 'name'})
-            .compute(
-                [
-                    ('database', form_sing_val_col(schema_relation.database)),
-                    ('schema', form_sing_val_col(schema_relation.schema)),
-                    ('type', form_sing_val_col('view')),
-                ]
-            )
-            .select(['database', 'name', 'schema', 'type'])
-        )
-        return agate_new
-
     @available.parse_none
     def make_field_partition_pairs(self, columns, partitions) -> List[str]:
         """
@@ -159,11 +140,26 @@ class FireboltAdapter(SQLAdapter):
         unpartitioned_columns = []
         partitioned_columns = []
         for column in columns:
+            # Don't need to check for name, as missing name fails at yaml parse time.
+            if column.get('data_type', None) is None:
+                raise dbt.exceptions.RuntimeException(
+                    f'Data type is missing for column `{column["name"]}`.'
+                )
             unpartitioned_columns.append(
                 self.quote(column['name']) + ' ' + column['data_type']
             )
         if partitions:  # partitions may be empty.
             for partition in partitions:
+                # Don't need to check for name, as missing name fails at
+                # yaml parse time.
+                if partition.get('data_type', None) is None:
+                    raise dbt.exceptions.RuntimeException(
+                        f'Data type is missing for partition `{partition["name"]}`.'
+                    )
+                if partition.get('regex', None) is None:
+                    raise dbt.exceptions.RuntimeException(
+                        f'Regex is missing for partition `{partition["name"]}`.'
+                    )
                 partitioned_columns.append(
                     self.quote(partition['name'])
                     + ' '
